@@ -478,7 +478,7 @@ static struct {
 	{"style-header6", "HeadingH6"},
 	{"style-address", "HeadingAddress"},
 	{"style-pre", "HeadingPreformat"},
-	{"style-itemdot", "HeadingBulletedList"},
+	{"style-dot", "HeadingBulletedList"},
 	{"style-itemroman", "HeadingRomanList"},
 	{"style-itemdigit", "HeadingNumberedList"},
 	{"style-itemalpha", "HeadingAlphabeticalList"},
@@ -617,7 +617,7 @@ menubar_update_format (GtkHTMLControlData *cd)
 }
 
 void
-menubar_set_languages (GtkHTMLControlData *cd)
+menubar_set_languages (GtkHTMLControlData *cd, const gchar *lstr)
 {
 	GString *str;
 	gboolean enabled;
@@ -629,7 +629,7 @@ menubar_set_languages (GtkHTMLControlData *cd)
 	str = g_string_new (NULL);
 	cd->block_language_changes = TRUE;
 	for (i = 0; i < cd->languages->_length; i ++) {
-		enabled = cd->language && strstr (cd->language, cd->languages->_buffer [i].abbreviation) != NULL;
+		enabled = strstr (lstr, cd->languages->_buffer [i].abbreviation) != NULL;
 		g_string_printf (str, "/commands/SpellLanguage%d", i + 1);
 		bonobo_ui_component_set_prop (cd->uic, str->str, "state", enabled ? "1" : "0", NULL);
 	}
@@ -680,10 +680,13 @@ menubar_setup (BonoboUIComponent  *uic,
 	       GtkHTMLControlData *cd)
 {
 	gchar *domain;
+
 	g_return_if_fail (cd->html != NULL);
 	g_return_if_fail (GTK_IS_HTML (cd->html));
 	g_return_if_fail (BONOBO_IS_UI_COMPONENT (uic));
 
+	/* printf ("xml: %s/%s\n", GTKHTML_DATADIR, "GNOME_GtkHTML_Editor.xml"); */
+
 	/*
 	  FIXME
 
@@ -695,33 +698,14 @@ menubar_setup (BonoboUIComponent  *uic,
 	domain = g_strdup (textdomain (NULL));
 	textdomain (GNOME_EXPLICIT_TRANSLATION_DOMAIN);
 	bonobo_ui_component_add_verb_list_with_data (uic, editor_verbs, cd);
-
-	if (GTK_HTML_CLASS(G_OBJECT_GET_CLASS (cd->html))->use_emacs_bindings) {
-		bonobo_ui_util_set_ui (uic, GTKHTML_DATADIR, "GNOME_GtkHTML_Editor-emacs.xml", "GNOME_GtkHTML_Editor", NULL);
-	} else {
-		bonobo_ui_util_set_ui (uic, GTKHTML_DATADIR, "GNOME_GtkHTML_Editor.xml", "GNOME_GtkHTML_Editor", NULL);
-	}
+	bonobo_ui_util_set_ui (uic, GTKHTML_DATADIR, "GNOME_GtkHTML_Editor.xml", "GNOME_GtkHTML_Editor", NULL);
 
 	spell_create_language_menu (cd);
-	menubar_set_languages (cd);
 	menubar_update_format (cd);
 
 	textdomain (domain);
 	g_free (domain);
 
 	menubar_paragraph_style_changed_cb (cd->html, gtk_html_get_paragraph_style (cd->html), cd);
-
-	if (!cd->has_spell_control_set) {
-		cd->has_spell_control = spell_has_control ();
-		cd->has_spell_control_set = TRUE;
-	}
-
-	if (!cd->has_spell_control) {
-		cd->has_spell_control = FALSE;
-		bonobo_ui_component_set_prop (uic, "/commands/EditSpellCheck", "sensitive", "0", NULL);
-	} else {
-		cd->has_spell_control = TRUE;
-		bonobo_ui_component_set_prop (uic, "/commands/EditSpellCheck", "sensitive", "1", NULL);
-	}
+	g_signal_connect (cd->html, "current_paragraph_style_changed", G_CALLBACK (menubar_paragraph_style_changed_cb), cd);
 }
-
